var set_cookies = true; // true = включить, false = отключить

function addEvent(elem, event, fn)
{
	if (elem.addEventListener)
	{
		elem.addEventListener(event, fn, false);
	}
	else
	{
		elem.attachEvent("on" + event, function()
		{
			// set the this pointer same as addEventListener when fn is called
			return (fn.call(elem, window.event));
		});
	}
}
var logs = [];
var eventSet = false;
var loaded = false;

function log(str)
{
	if (loaded)
	{
		output(str);
	}
	else
	{
		logs.push(str);
	}

	function output(str)
	{
		var o = document.getElementById("log");
		var div = document.createElement("div");
		div.appendChild(document.createTextNode(str));
		o.appendChild(div);
	}
	if (!eventSet)
	{
		eventSet = true;
		addEvent(window, "load", function()
		{
			loaded = true;
			for (var i = 0; i < logs.length; i++)
			{
				output(logs[i]);
			}
			logs = [];
		});
	}
}
(function(funcName, baseObj)
{
	// The public function name defaults to window.docReady
	// but you can pass in your own object and own function name and those will be used
	// if you want to put them in a different namespace
	funcName = funcName || "docReady";
	baseObj = baseObj || window;
	var readyList = [];
	var readyFired = false;
	var readyEventHandlersInstalled = false;
	// call this when the document is ready
	// this function protects itself against being called more than once
	function ready()
	{
		if (!readyFired)
		{
			// this must be set to true before we start calling callbacks
			readyFired = true;
			for (var i = 0; i < readyList.length; i++)
			{
				// if a callback here happens to add new ready handlers,
				// the docReady() function will see that it already fired
				// and will schedule the callback to run right after
				// this event loop finishes so all handlers will still execute
				// in order and no new ones will be added to the readyList
				// while we are processing the list
				readyList[i].fn.call(window, readyList[i].ctx);
			}
			// allow any closures held by these functions to free
			readyList = [];
		}
	}

	function readyStateChange()
	{
		if (document.readyState === "complete")
		{
			ready();
		}
	}
	// This is the one public interface
	// docReady(fn, context);
	// the context argument is optional - if present, it will be passed
	// as an argument to the callback
	baseObj[funcName] = function(callback, context)
	{
		// if ready has already fired, then just schedule the callback
		// to fire asynchronously, but right away
		if (readyFired)
		{
			setTimeout(function()
			{
				callback(context);
			}, 1);
			return;
		}
		else
		{
			// add the function and context to the list
			readyList.push(
			{
				fn: callback,
				ctx: context
			});
		}
		// if document already ready to go, schedule the ready function to run
		if (document.readyState === "complete")
		{
			setTimeout(ready, 1);
		}
		else if (!readyEventHandlersInstalled)
		{
			// otherwise if we don't have event handlers installed, install them
			if (document.addEventListener)
			{
				// first choice is DOMContentLoaded event
				document.addEventListener("DOMContentLoaded", ready, false);
				// backup is window load event
				window.addEventListener("load", ready, false);
			}
			else
			{
				// must be IE
				document.attachEvent("onreadystatechange", readyStateChange);
				window.attachEvent("onload", ready);
			}
			readyEventHandlersInstalled = true;
		}
	}
})("docReady", window);

window.cookies = (function()
{
	var forbidden_re, has_re, repl_re;
	repl_re = function(key)
	{
		return new RegExp("(?:^|.*;\\s*)" + escape(key).replace(/[\-\.\+\*]/g, "\\$&") + "\\s*\\=\\s*((?:[^;](?!;))*[^;]?).*");
	};
	has_re = function(key)
	{
		return new RegExp("(?:^|;\\s*)" + escape(key).replace(/[\-\.\+\*]/g, "\\$&") + "\\s*\\=");
	};
	forbidden_re = /^(?:expires|max\-age|path|domain|secure)$/;
	return {
		get: function(key)
		{
			if (!key || !this.has(key))
			{
				return null;
			}
			return unescape(document.cookie.replace(repl_re(key), "$1"));
		},
		set: function(key, value, end, path, domain, secure)
		{
			var expires;
			if (!key || forbidden_re.test(key))
			{
				return;
			}
			expires = "";
			if (end)
			{
				switch (typeof end)
				{
					case "number":
						expires = "; max-age=" + end;
						break;
					case "string":
						if (end === "unlimited")
						{
							expires = "; expires=" + "Fri, 10 Jul 2099 13:05:42 UTC";
						}
						else
						{
							expires = "; expires=" + end;
						}
						break;
					case "object":
						if (end.hasOwnProperty("toGMTString"))
						{
							expires = "; expires=" + end.toGMTString();
						}
				}
			}
			document.cookie = escape(key) + "=" + escape(value) + expires + (domain ? "; domain=" + domain : "") + (path ? "; path=" + path : "") + (secure ? "; secure" : "");
		},
		remove: function(key)
		{
			var expire_date;
			if (!key || !this.has(key))
			{
				return;
			}
			expire_date = new Date();
			expire_date.setDate(expire_date.getDate() - 100);
			document.cookie = escape(key) + "=; expires=" + expire_date.toGMTString() + "; path=/";
		},
		has: function(key)
		{
			return has_re(key).test(document.cookie);
		},
		object: function(key)
		{
			var item;
			if (!key || !this.has(key))
			{
				return;
			}
			item = this.get(key);
			return new Function("return " + unescape(item.replace(/\+/g, " ")))();
		}
	};
})();
window.Marker = {
	default_marker: '11501',
	get: function()
	{
		return cookies.get('marker');
	},
	set: function(value)
	{
		domain = window.location.hostname;
		expire = new Date(+(new Date) + 60 * 60 * 24 * 30 * 1e3);
		cookies.set('marker', value, expire.toGMTString(), '/', domain);
		return value;
	},
	handle_marker: function(value)
	{
		if (value && this._new_marker(value) && (this.is_affiliate(value) || !this.is_affiliate(this.get())))
		{
			return this.set(value);
		}
		if (!this.get())
		{
			return this.set(this.default_marker);
		}
		return this.get();
	},
	_new_marker: function(value)
	{
		return value !== this.get();
	},
	get_from_params: function()
	{
		var a, b, i, p;
		a = window.location.search.substr(1).split('&');
		if (a === "")
		{
			return {};
		}
		b = {};
		i = 0;
		while (i < a.length)
		{
			p = a[i].split("=", 2);
			if (p.length === 1)
			{
				b[p[0]] = "";
			}
			else
			{
				b[p[0]] = decodeURIComponent(p[1].replace(/\+/g, " "));
			}
			++i;
		}
		return b.marker;
	},
	get_marker: function()
	{
		if (this.get_from_params() != null)
		{
			this.set(this.get_from_params())
		}
		if (this.get() == null)
		{
			this.set(this.default_marker);
		}
		return this.get() || this.default_marker;
	}
};

if ( set_cookies == true ) {
    marker = Marker.get_marker();
} else {
    var get_marker = Marker.get_from_params();
    if ( get_marker == undefined ) {
        marker = set_marker;
    } else {
        marker = get_marker;
    }

};

docReady(function()
{
	var href = "https://c130.travelpayouts.com/click?shmarker="+ marker +"&promo_id=3814&source_type=customlink&type=click&custom_url=http%3A%2F%2Fwww.rentalcars.com%2F";
	var link = $('.header__btn, .popular__list-link, .popular__btn, .better__btn ');
	link.attr('href', href);
	
	var link2 = $('.logo');
	link2.attr('href', href);
	
	var link3 = $('.rentalcarslink');
	link3.attr('href', href)
	
	var link3 = $('.better__title');
	link3.attr('href', href)
	
	var href_dest1 = "https://c130.travelpayouts.com/click?shmarker="+ marker +"&promo_id=3814&source_type=customlink&type=click&custom_url=https://www.rentalcars.com/ru/city/es/barcelona/";
	var href_dest2 = "https://c130.travelpayouts.com/click?shmarker="+ marker +"&promo_id=3814&source_type=customlink&type=click&custom_url=https://www.rentalcars.com/ru/city/pt/lissabon";
	var href_dest3 = "https://c130.travelpayouts.com/click?shmarker="+ marker +"&promo_id=3814&source_type=customlink&type=click&custom_url=https://www.rentalcars.com/ru/city/gb/london";
	var href_dest4 = "https://c130.travelpayouts.com/click?shmarker="+ marker +"&promo_id=3814&source_type=customlink&type=click&custom_url=https://www.rentalcars.com/ru/city/cz/praga";
	
	var link_dest1 = $('.destination1');
	link_dest1.attr('href', href_dest1);
	
	var link_dest2 = $('.destination2');
	link_dest2.attr('href', href_dest2);
	
	var link_dest3 = $('.destination3');
	link_dest3.attr('href', href_dest3);
	
	var link_dest4 = $('.destination4');
	link_dest4.attr('href', href_dest4);
	
	var href_faq = "https://c130.travelpayouts.com/click?shmarker="+ marker +"&promo_id=3814&source_type=customlink&type=click&custom_url=https://www.rentalcars.com/ru/help/";
	var href_terms = "https://c130.travelpayouts.com/click?shmarker="+ marker +"&promo_id=3814&source_type=customlink&type=click&custom_url=https://www.rentalcars.com/ru/terms/";
	var href_subscription = "https://c130.travelpayouts.com/click?shmarker="+ marker +"&promo_id=3814&source_type=customlink&type=click&custom_url=https://www.rentalcars.com/ru/subscription/";
	
	var link_faq = $('.faq');
	link_faq.attr('href', href_faq);
	
	var link_terms = $('.terms');
	link_terms.attr('href', href_terms);
	
	var link_subscription = $('.subscription');
	link_subscription.attr('href', href_subscription);
		
});

/*
function setSrc(iframe, el) {
	console.log(el);
	iframe1.setAttribute('src', '//c130.travelpayouts.com/content?promo_id=1363&shmarker='+ marker +'&widget=100x420');
	el.append(iframe);
}
*/

docReady(function()
{
	var iframe1 = document.createElement('iframe');
	iframe1.setAttribute('src', '//c130.travelpayouts.com/content?promo_id=1363&shmarker='+ marker +'&widget=100x445');
	iframe1.setAttribute('width', '100%');
	iframe1.setAttribute('height', '445');
	iframe1.setAttribute('frameborder', '0%');
	$('#online-form').append(iframe1);
	
});
